@@ -1,6 +1,4 @@
-from __future__ import unicode_literals
-
-import mock
+from unittest import mock
 
 import pytest
 
@@ -13,10 +11,10 @@ def audio():
 @pytest.fixture
 def config():
     return {
-        'dleyna': {
-            'upnp_browse_limit': 1000,
-            'upnp_lookup_limit': 50,
-            'upnp_search_limit': 100
+        "dleyna": {
+            "upnp_browse_limit": 1000,
+            "upnp_lookup_limit": 50,
+            "upnp_search_limit": 100,
         }
     }
 
@@ -31,12 +29,9 @@ def client():
 def backend(config, audio, client):
     from mopidy import backend
     from mopidy_dleyna import library, playback
+
     backend_mock = mock.Mock(spec=backend.Backend)
     backend_mock.client = client
-    backend_mock.library = library.dLeynaLibraryProvider(
-        backend_mock, config
-    )
-    backend_mock.playback = playback.dLeynaPlaybackProvider(
-        audio, backend_mock
-    )
+    backend_mock.library = library.dLeynaLibraryProvider(backend_mock, config)
+    backend_mock.playback = playback.dLeynaPlaybackProvider(audio, backend_mock)
     return backend_mock
